@@ -13,10 +13,10 @@ if (@ARGV < 1) {
 my $file = $ARGV[0];
 
 # Check DWG file.
-my $dwg_flag = detect_dwg_file($file);
+my $dwg_magic = detect_dwg_file($file);
 
 # Print out.
-if ($dwg_flag) {
+if ($dwg_magic) {
         print "File '$file' is DWG file.\n";
 } else {
         print "File '$file' isn't DWG file.\n";
